%{!?_with_bootstrap: %global bootstrap 0}
%global with_python2 0%{?fedora} && 0%{?fedora} < 30

Name:           conda
Version:        4.7.2
Release:        1%{?dist}
Summary:        Cross-platform, Python-agnostic binary package manager

License:        BSD and ASL 2.0 and LGPLv2+ and MIT
# The conda code is BSD
# progressbar is LGPLv2+
# six is MIT/X11
# adapters/ftp.py is ASL 2.0

URL:            http://conda.pydata.org/docs/
Source0:        https://github.com/conda/conda/archive/%{version}/%{name}-%{version}.tar.gz
# Source0:        https://pypi.io/packages/source/c/%%{name}/%%{name}-%%{version}.tar.gz
Patch0:         conda_sys_prefix.patch
Patch1:         conda_gateways_disk_create.patch
Patch2:         setup.patch

Patch10001:     0001-Fix-toolz-imports.patch
Patch10002:     0002-Adjust-ruamel.yaml-imports.patch
Patch10003:     0003-Drop-fs-path-encoding-manipulation-under-python2.patch
Patch10004:     0004-Do-not-try-to-run-usr-bin-python.patch
Patch10005:     0005-Fix-failing-tests-in-test_api.py.patch

BuildArch:      noarch

Requires:       python%{python3_pkgversion}-conda = %{version}-%{release}
# Removed upstream in favour of calling "conda activate" in version 4.4.0
Obsoletes:	conda-activate < 4.4

%?python_enable_dependency_generator

BuildRequires:  sed

%global _description \
Conda is a cross-platform, Python-agnostic binary package manager. It is the\
package manager used by Anaconda installations, but it may be used for other\
systems as well. Conda makes environments first-class citizens, making it easy\
to create independent environments even for C libraries. Conda is written\
entirely in Python.

%description %_description

%global _py2_reqs \
        python2-crypto \
        python2-pycosat >= 0.6.3 \
        python2-ruamel-yaml \
        python2-mock \
        python2-responses

%global _py2_bund \
        bundled(python2-appdirs) = 1.2.0 \
        bundled(python2-auxlib) \
        bundled(python2-boltons) = 16.5.1 \
        bundled(python2-six) = 1.10.0 \
        bundled(python2-toolz) = 0.8.2 \
        bundled(python2-urllib3) = 1.19.1

%global py2_reqs %(c="%_py2_reqs"; echo "$c" | xargs)
%global py3_reqs %(c="%_py2_reqs"; echo "$c" | sed s/python2/python%{python3_pkgversion}/ | xargs)

%global py2_bund %(c="%_py2_bund"; echo "$c" | xargs)
%global py3_bund %(c="%_py2_bund"; echo "$c" | sed s/python2/python%{python3_pkgversion}/ | xargs)

%if %with_python2
%package -n python2-conda
Summary:        %{summary}

BuildRequires:  python2-devel
BuildRequires:  python2-setuptools
BuildRequires:  %py2_reqs
BuildRequires:  python2-requests
# When this is present, vendored toolz should not be used
%if 0%{?fedora}
# EPEL does not have new enough cytoolz
BuildRequires:  python2-cytoolz
%endif
# For tests
BuildRequires:  python2-conda-package-handling >= 1.3.0
BuildRequires:  python2-enum34
BuildRequires:  python2-futures
BuildRequires:  python2-pytest-cov

# Keep manual Requires for now:
# automatically generated Requires are missing a few modules.
# Having both is still useful because the automatic ones have
# version requirements.
Requires:       %py2_reqs
Requires:       python2-conda-package-handling >= 1.3.0
Requires:       python2-enum34
Requires:       python2-futures
%if 0%{?fedora}
# EPEL does not have new enough cytoolz
Requires:       python2-cytoolz
%endif
Provides:       %py2_bund
%{?python_provide:%python_provide python2-conda}

%description -n python2-conda %_description
%endif

%package -n python%{python3_pkgversion}-conda
Summary:        %{summary}

BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-setuptools
BuildRequires:  %py3_reqs
BuildRequires:  python%{python3_pkgversion}-requests
BuildRequires:  python%{python3_pkgversion}-yaml
# When this is present, vendored toolz should not be used
%if 0%{?fedora}
# EPEL does not have new enough cytoolz
BuildRequires:  python%{python3_pkgversion}-cytoolz >= 0.8.2
%endif
# For tests
BuildRequires:  python%{python3_pkgversion}-conda-package-handling >= 1.3.0
BuildRequires:  python%{python3_pkgversion}-pytest-cov

Requires:       %py3_reqs
Requires:       python%{python3_pkgversion}-conda-package-handling >= 1.3.0
Requires:       python%{python3_pkgversion}-requests
Requires:       python%{python3_pkgversion}-yaml
%if 0%{?fedora}
# EPEL does not have new enough cytoolz
Requires:       python%{python3_pkgversion}-cytoolz >= 0.8.2
%endif
Provides:       %py3_bund
%{?python_provide:%python_provide python%{python3_pkgversion}-conda}

%description -n python%{python3_pkgversion}-conda %_description

%prep
%autosetup -p1

sed -r -i 's/^(__version__ = ).*/\1"%{version}"/' conda/__init__.py

# disable some stupid tests which fail with EXDEV
sed -r -i 's/test_trash_outside_prefix/_disabled_\0/' tests/test_install.py
sed -r -i 's/test_move_to_trash|test_move_path_to_trash_couldnt/_disabled_\0/' tests/gateways/disk/test_delete.py

# Skip TestJson.test_list which wants to muck around with /usr.
sed -r -i 's/\btest_list\b/_disabled_\0/' tests/test_cli.py

# delete interpreter line, the user can always call the file
# explicitly as python3 /usr/lib/python3.6/site-packages/conda/_vendor/appdirs.py
# or so.
sed -r -i '1 {/#![/]usr[/]bin[/]env/d}' conda/_vendor/appdirs.py

# Replaced by cytools, byte compilation fails under python3.7
%if 0%{?fedora}
# EPEL does not have new enough cytoolz
# We need to keep __init__.py which does the dispatch between vendored and non-vendored
rm conda/_vendor/toolz/[a-zA-Z]*
%endif

%build
# build conda executable
%define py_setup utils/setup-testing.py
%if %with_python2
%py2_build
%endif
%py3_build

%install
# install conda executable
%define py_setup utils/setup-testing.py
%if 0%{?fedora}
%if %with_python2
%py2_install
%endif
%py3_install
%else
%py3_install
%if %with_python2
%py2_install
%endif
%endif

mkdir -p %{buildroot}%{_datadir}/conda/condarc.d
cat >%{buildroot}%{_datadir}/conda/condarc.d/defaults.yaml <<EOF
pkgs_dirs:
 - /var/cache/conda/pkgs
 - ~/.conda/pkgs
EOF

mkdir -p %{buildroot}%{_localstatedir}/cache/conda/pkgs/cache

# install does not create the directory on EL7
mkdir -p %{buildroot}%{_sysconfdir}/profile.d
install -m 0644 -Dt %{buildroot}/etc/profile.d/ conda/shell/etc/profile.d/conda.{sh,csh}
sed -r -i '1i CONDA_EXE=%{_bindir}/conda' %{buildroot}/etc/profile.d/conda.sh
sed -r -i -e '1i set _CONDA_EXE=%{_bindir}/conda\nset _CONDA_ROOT=' \
          -e 's/CONDA_PFX=.*/CONDA_PFX=/' %{buildroot}/etc/profile.d/conda.csh

%check
export PATH=%{buildroot}%{_bindir}:$PATH

# Integration tests generally require network, so skip them.
# tests/core/test_initialize.py tries to unlink /usr/bin/python3
# test_create_advanced_pip connects to pypi
py.test-%{python3_version} -vv -m "not integration" \
    -k 'not test_create_advanced_pip' \
    --ignore tests/core/test_initialize.py %{?el7:|| :}

%if %with_python2
# Run python2 tests later, since they are more likely to fail stupidly.
# Some tests fail because py2 does not default to utf-8.
py.test-%{python2_version} -vv -m "not integration" -k "not test_unicode"
%endif

%files
%{_bindir}/conda
%{_bindir}/conda-env
/etc/profile.d/conda.sh
/etc/profile.d/conda.csh

%if %with_python2
%files -n python2-conda
%license LICENSE.txt
%doc CHANGELOG.md README.rst
%{python2_sitelib}/conda/
%{python2_sitelib}/conda_env/
%{python2_sitelib}/*.egg-info
%exclude %{python2_sitelib}/test_data/
%{_localstatedir}/cache/conda/
%{_datadir}/conda/
%endif

%files -n python%{python3_pkgversion}-conda
%license LICENSE.txt
%doc CHANGELOG.md README.rst
%{python3_sitelib}/conda/
%{python3_sitelib}/conda_env/
%{python3_sitelib}/*.egg-info
%exclude %{python3_sitelib}/test_data/
%{_localstatedir}/cache/conda/
%{_datadir}/conda/


%changelog
* Tue Jun 11 2019 Orion Poplawski <orion@nwra.com> - 4.7.2-1
- Update to 4.7.2

* Sun Jun  9 2019 Orion Poplawski <orion@nwra.com> - 4.7.1-1
- Update to 4.7.1

* Tue Apr 16 2019 Orion Poplawski <orion@nwra.com> - 4.6.13-1
- Update to 4.6.13

* Thu Apr  4 2019 Orion Poplawski <orion@nwra.com> - 4.6.11-1
- Update to 4.6.11

* Tue Apr  2 2019 Orion Poplawski <orion@nwra.com> - 4.6.9-2
- Fix conda profile scripts
- Do not build for python2 on EPEL
- Ignore test failures on EPEL7

* Sat Mar 30 2019 Orion Poplawski <orion@nwra.com> - 4.6.9-1
- Update to 4.6.9

* Wed Feb 13 2019 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 4.6.5-1
- Update to latest upstream version (#1668145)

* Thu Jan 31 2019 Fedora Release Engineering <releng@fedoraproject.org> - 4.5.12-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Mon Dec 31 2018 Orion Poplawski <orion@nwra.com> - 4.5.12-1
- Update to 4.5.12

* Mon Dec 31 2018 Orion Poplawski <orion@nwra.com> - 4.5.11-2
- EPEL7 compatability

* Fri Sep 21 2018 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 4.5.11-1
- Update to latest stable version (#1570217)
- Disable python2 subpackage on F30+

* Fri Jul 13 2018 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 4.4.11-4
- Pull in python[23]-cytoolz to replace bundled toolz

* Thu Jul 12 2018 Fedora Release Engineering <releng@fedoraproject.org> - 4.4.11-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 4.4.11-3
- Rebuilt for Python 3.7

* Wed Apr 18 2018 Orion Poplawski <orion@nwra.com> - 4.4.11-2
- Set _CONDA_ROOT in /etc/profile.d/conda.csh
- Fix python2 requires
- Require pycosat >= 0.6.3

* Sat Apr 14 2018 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 4.4.11-1
- Update to latest upstream version in the 4.4.x branch (#1544046)

* Wed Feb  7 2018 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 4.4.9-1
- Update to v4.4.9 (#1542874)
- conda-activate binary rpm is retired. The new way to activate the environment
  is to say 'conda activate'. See
  https://github.com/conda/conda/releases/tag/4.4.0 for more information.

* Wed Feb 07 2018 Iryna Shcherbina <ishcherb@redhat.com> - 4.3.24-5
- Update Python 2 dependency declarations to new packaging standards
  (See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3)

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 4.3.24-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Sun Aug 20 2017 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 4.3.24-3
- Install just one version of the executables (python 2 or 3)

* Sun Aug 20 2017 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 4.3.24-2
- Add all licenses to the License tag
- Add Provides: bundled(...) for all the "vendored" dependencies
- Update descriptions and simplify the spec file a bit
- Move condarc.d directory under /usr/share/conda

* Thu Aug  3 2017 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 4.3.24-1
- Update to latest version
- Switch /usr/bin/conda to python3

* Thu Jul 21 2016 Orion Poplawski <orion@cora.nwra.com> - 4.1.6-1
- Update to 4.1.6

* Thu Dec 31 2015 Orion Poplawski <orion@cora.nwra.com> - 3.19.0-1
- Update to 3.19.0

* Thu Dec 31 2015 Orion Poplawski <orion@cora.nwra.com> - 3.18.8-2
- Add python 3 version

* Mon Dec 7 2015 Orion Poplawski <orion@cora.nwra.com> - 3.18.8-1
- Update to 3.18.8

* Thu Sep 24 2015 Orion Poplawski <orion@cora.nwra.com> - 3.17.0-6
- Do not create broken symlinks if activate/deactivate are not installed
- Do not create /usr/conda-meta to prevent accidental installs into system

* Thu Sep 24 2015 Orion Poplawski <orion@cora.nwra.com> - 3.17.0-5
- Non-bootstrap build

* Wed Sep 23 2015 Orion Poplawski <orion@cora.nwra.com> - 3.17.0-4
- Add patch to support rootless mode
- Require python-crypto
- Create /usr/conda-meta, /usr/.condarc, /var/cache/conda

* Tue Sep 22 2015 Orion Poplawski <orion@cora.nwra.com> - 3.17.0-3
- Require python-requests, python-yaml

* Tue Sep 22 2015 Orion Poplawski <orion@cora.nwra.com> - 3.17.0-2
- Add patch to allow overriding pkgs_dirs in .condarc

* Mon Sep 21 2015 Orion Poplawski <orion@cora.nwra.com> - 3.17.0-1
- Initial package
